==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/github/workflows/JobMatrix.java <==
package io.github.cdklabs.projen.github.workflows;

/**
 * (experimental) A job matrix.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.781Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.workflows.JobMatrix")
@software.amazon.jsii.Jsii.Proxy(JobMatrix.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface JobMatrix extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Each option you define in the matrix has a key and value.
     * <p>
     * The keys you
     * define become properties in the matrix context and you can reference the
     * property in other areas of your workflow file. For example, if you define
     * the key os that contains an array of operating systems, you can use the
     * matrix.os property as the value of the runs-on keyword to create a job
     * for each operating system.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.Map<java.lang.String, java.util.List<java.lang.String>> getDomain() {
        return null;
    }

    /**
     * (experimental) You can remove a specific configurations defined in the build matrix using the exclude option.
     * <p>
     * Using exclude removes a job defined by the
     * build matrix.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.util.Map<java.lang.String, java.lang.String>> getExclude() {
        return null;
    }

    /**
     * (experimental) You can add additional configuration options to a build matrix job that already exists.
     * <p>
     * For example, if you want to use a specific version of npm
     * when the job that uses windows-latest and version 8 of node runs, you can
     * use include to specify that additional option.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.util.Map<java.lang.String, java.lang.String>> getInclude() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link JobMatrix}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link JobMatrix}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<JobMatrix> {
        java.util.Map<java.lang.String, java.util.List<java.lang.String>> domain;
        java.util.List<java.util.Map<java.lang.String, java.lang.String>> exclude;
        java.util.List<java.util.Map<java.lang.String, java.lang.String>> include;

        /**
         * Sets the value of {@link JobMatrix#getDomain}
         * @param domain Each option you define in the matrix has a key and value.
         *               The keys you
         *               define become properties in the matrix context and you can reference the
         *               property in other areas of your workflow file. For example, if you define
         *               the key os that contains an array of operating systems, you can use the
         *               matrix.os property as the value of the runs-on keyword to create a job
         *               for each operating system.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder domain(java.util.Map<java.lang.String, ? extends java.util.List<java.lang.String>> domain) {
            this.domain = (java.util.Map<java.lang.String, java.util.List<java.lang.String>>)domain;
            return this;
        }

        /**
         * Sets the value of {@link JobMatrix#getExclude}
         * @param exclude You can remove a specific configurations defined in the build matrix using the exclude option.
         *                Using exclude removes a job defined by the
         *                build matrix.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder exclude(java.util.List<? extends java.util.Map<java.lang.String, java.lang.String>> exclude) {
            this.exclude = (java.util.List<java.util.Map<java.lang.String, java.lang.String>>)exclude;
            return this;
        }

        /**
         * Sets the value of {@link JobMatrix#getInclude}
         * @param include You can add additional configuration options to a build matrix job that already exists.
         *                For example, if you want to use a specific version of npm
         *                when the job that uses windows-latest and version 8 of node runs, you can
         *                use include to specify that additional option.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder include(java.util.List<? extends java.util.Map<java.lang.String, java.lang.String>> include) {
            this.include = (java.util.List<java.util.Map<java.lang.String, java.lang.String>>)include;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link JobMatrix}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public JobMatrix build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link JobMatrix}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements JobMatrix {
        private final java.util.Map<java.lang.String, java.util.List<java.lang.String>> domain;
        private final java.util.List<java.util.Map<java.lang.String, java.lang.String>> exclude;
        private final java.util.List<java.util.Map<java.lang.String, java.lang.String>> include;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.domain = software.amazon.jsii.Kernel.get(this, "domain", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))));
            this.exclude = software.amazon.jsii.Kernel.get(this, "exclude", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))));
            this.include = software.amazon.jsii.Kernel.get(this, "include", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.domain = (java.util.Map<java.lang.String, java.util.List<java.lang.String>>)builder.domain;
            this.exclude = (java.util.List<java.util.Map<java.lang.String, java.lang.String>>)builder.exclude;
            this.include = (java.util.List<java.util.Map<java.lang.String, java.lang.String>>)builder.include;
        }

        @Override
        public final java.util.Map<java.lang.String, java.util.List<java.lang.String>> getDomain() {
            return this.domain;
        }

        @Override
        public final java.util.List<java.util.Map<java.lang.String, java.lang.String>> getExclude() {
            return this.exclude;
        }

        @Override
        public final java.util.List<java.util.Map<java.lang.String, java.lang.String>> getInclude() {
            return this.include;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getDomain() != null) {
                data.set("domain", om.valueToTree(this.getDomain()));
            }
            if (this.getExclude() != null) {
                data.set("exclude", om.valueToTree(this.getExclude()));
            }
            if (this.getInclude() != null) {
                data.set("include", om.valueToTree(this.getInclude()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.github.workflows.JobMatrix"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            JobMatrix.Jsii$Proxy that = (JobMatrix.Jsii$Proxy) o;

            if (this.domain != null ? !this.domain.equals(that.domain) : that.domain != null) return false;
            if (this.exclude != null ? !this.exclude.equals(that.exclude) : that.exclude != null) return false;
            return this.include != null ? this.include.equals(that.include) : that.include == null;
        }

        @Override
        public final int hashCode() {
            int result = this.domain != null ? this.domain.hashCode() : 0;
            result = 31 * result + (this.exclude != null ? this.exclude.hashCode() : 0);
            result = 31 * result + (this.include != null ? this.include.hashCode() : 0);
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/github/workflows/JobMatrix.java <==
package io.github.cdklabs.projen.github.workflows;

/**
 * (experimental) A job matrix.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.448Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.workflows.JobMatrix")
@software.amazon.jsii.Jsii.Proxy(JobMatrix.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface JobMatrix extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Each option you define in the matrix has a key and value.
     * <p>
     * The keys you
     * define become properties in the matrix context and you can reference the
     * property in other areas of your workflow file. For example, if you define
     * the key os that contains an array of operating systems, you can use the
     * matrix.os property as the value of the runs-on keyword to create a job
     * for each operating system.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.Map<java.lang.String, java.util.List<java.lang.Object>> getDomain() {
        return null;
    }

    /**
     * (experimental) You can remove a specific configurations defined in the build matrix using the exclude option.
     * <p>
     * Using exclude removes a job defined by the
     * build matrix.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.util.Map<java.lang.String, java.lang.Object>> getExclude() {
        return null;
    }

    /**
     * (experimental) You can add additional configuration options to a build matrix job that already exists.
     * <p>
     * For example, if you want to use a specific version of npm
     * when the job that uses windows-latest and version 8 of node runs, you can
     * use include to specify that additional option.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.List<java.util.Map<java.lang.String, java.lang.Object>> getInclude() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link JobMatrix}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link JobMatrix}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<JobMatrix> {
        java.util.Map<java.lang.String, java.util.List<java.lang.Object>> domain;
        java.util.List<java.util.Map<java.lang.String, java.lang.Object>> exclude;
        java.util.List<java.util.Map<java.lang.String, java.lang.Object>> include;

        /**
         * Sets the value of {@link JobMatrix#getDomain}
         * @param domain Each option you define in the matrix has a key and value.
         *               The keys you
         *               define become properties in the matrix context and you can reference the
         *               property in other areas of your workflow file. For example, if you define
         *               the key os that contains an array of operating systems, you can use the
         *               matrix.os property as the value of the runs-on keyword to create a job
         *               for each operating system.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder domain(java.util.Map<java.lang.String, ? extends java.util.List<? extends java.lang.Object>> domain) {
            this.domain = (java.util.Map<java.lang.String, java.util.List<java.lang.Object>>)domain;
            return this;
        }

        /**
         * Sets the value of {@link JobMatrix#getExclude}
         * @param exclude You can remove a specific configurations defined in the build matrix using the exclude option.
         *                Using exclude removes a job defined by the
         *                build matrix.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder exclude(java.util.List<? extends java.util.Map<java.lang.String, ? extends java.lang.Object>> exclude) {
            this.exclude = (java.util.List<java.util.Map<java.lang.String, java.lang.Object>>)exclude;
            return this;
        }

        /**
         * Sets the value of {@link JobMatrix#getInclude}
         * @param include You can add additional configuration options to a build matrix job that already exists.
         *                For example, if you want to use a specific version of npm
         *                when the job that uses windows-latest and version 8 of node runs, you can
         *                use include to specify that additional option.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @SuppressWarnings("unchecked")
        public Builder include(java.util.List<? extends java.util.Map<java.lang.String, ? extends java.lang.Object>> include) {
            this.include = (java.util.List<java.util.Map<java.lang.String, java.lang.Object>>)include;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link JobMatrix}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public JobMatrix build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link JobMatrix}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements JobMatrix {
        private final java.util.Map<java.lang.String, java.util.List<java.lang.Object>> domain;
        private final java.util.List<java.util.Map<java.lang.String, java.lang.Object>> exclude;
        private final java.util.List<java.util.Map<java.lang.String, java.lang.Object>> include;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.domain = software.amazon.jsii.Kernel.get(this, "domain", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.Object.class))));
            this.exclude = software.amazon.jsii.Kernel.get(this, "exclude", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.Object.class))));
            this.include = software.amazon.jsii.Kernel.get(this, "include", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.Object.class))));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        @SuppressWarnings("unchecked")
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.domain = (java.util.Map<java.lang.String, java.util.List<java.lang.Object>>)builder.domain;
            this.exclude = (java.util.List<java.util.Map<java.lang.String, java.lang.Object>>)builder.exclude;
            this.include = (java.util.List<java.util.Map<java.lang.String, java.lang.Object>>)builder.include;
        }

        @Override
        public final java.util.Map<java.lang.String, java.util.List<java.lang.Object>> getDomain() {
            return this.domain;
        }

        @Override
        public final java.util.List<java.util.Map<java.lang.String, java.lang.Object>> getExclude() {
            return this.exclude;
        }

        @Override
        public final java.util.List<java.util.Map<java.lang.String, java.lang.Object>> getInclude() {
            return this.include;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getDomain() != null) {
                data.set("domain", om.valueToTree(this.getDomain()));
            }
            if (this.getExclude() != null) {
                data.set("exclude", om.valueToTree(this.getExclude()));
            }
            if (this.getInclude() != null) {
                data.set("include", om.valueToTree(this.getInclude()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.github.workflows.JobMatrix"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            JobMatrix.Jsii$Proxy that = (JobMatrix.Jsii$Proxy) o;

            if (this.domain != null ? !this.domain.equals(that.domain) : that.domain != null) return false;
            if (this.exclude != null ? !this.exclude.equals(that.exclude) : that.exclude != null) return false;
            return this.include != null ? this.include.equals(that.include) : that.include == null;
        }

        @Override
        public final int hashCode() {
            int result = this.domain != null ? this.domain.hashCode() : 0;
            result = 31 * result + (this.exclude != null ? this.exclude.hashCode() : 0);
            result = 31 * result + (this.include != null ? this.include.hashCode() : 0);
            return result;
        }
    }
}
